package com.tuoheng.admin.service.airport.drone;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.tuoheng.admin.conver.InspectionConverMapper;
import com.tuoheng.admin.entity.domain.Tenant;
import com.tuoheng.admin.entity.domain.ThInspection;
import com.tuoheng.admin.entity.domain.ThMission;
import com.tuoheng.admin.entity.vo.index.DroneDataVo;
import com.tuoheng.admin.enums.TaskStatusEnum;
import com.tuoheng.admin.mapper.TenantMapper;
import com.tuoheng.admin.mapper.ThInspectionMapper;
import com.tuoheng.admin.mapper.ThMissionMapper;
import com.tuoheng.common.exception.ServiceException;
import com.tuoheng.common.utils.JsonResult;
import com.tuoheng.common.utils.StringUtils;
import com.tuoheng.system.entity.User;
import com.tuoheng.system.utils.ShiroUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Slf4j
@Service
public class QueryDroneDataService {

    @Autowired
    private TenantMapper tenantMapper;

    @Autowired
    private ThMissionMapper missionMapper;

    @Autowired
    private ThInspectionMapper inspectionMapper;

    public JsonResult getDroneDataById(String airportId) {
        log.info("获取无人机数据信息");

        this.check(airportId);

        // 读取不同租户的机场平台url
        User user = ShiroUtils.getUserInfo();
        Integer tenantId = user.getTenantId();

        ThMission mission = missionMapper.selectOne(new LambdaQueryWrapper<ThMission>()
                .eq(ThMission::getTenantId, tenantId)
                .eq(ThMission::getStatus, TaskStatusEnum.FLIGHT.getCode())
                .eq(ThMission::getAirportId, airportId)
                .eq(ThMission::getMark, 1));
        if (ObjectUtil.isNull(mission)) {
            throw new ServiceException("没有正在飞行的任务");
        }

        List<ThInspection> inspectionList = inspectionMapper.selectListByMissionId(mission.getId(), ShiroUtils.getTenantId());
        if (CollectionUtil.isEmpty(inspectionList)) {
            JsonResult.success("无人机数据为空");
        }
        List<DroneDataVo> droneDataVoList = InspectionConverMapper.INSTANCE.fromInspectionListToDroneDataVoList(inspectionList);
        return JsonResult.success(droneDataVoList);
    }

    /**
     * 检查参数
     *
     * @param airportId
     * @return
     */
    private void check(String airportId) {
        if (StringUtils.isEmpty(airportId)) {
            throw new ServiceException("机场ID为空");
        }
    }

    /**
     * 获取租户
     *
     * @param tenantId
     * @return
     */
    private Tenant getTenant(Integer tenantId) {
        Tenant tenant = tenantMapper.selectById(tenantId);
        if (ObjectUtil.isEmpty(tenant)) {
            log.info("调用机场平台，操作无人机: 租户不存在");
            throw new ServiceException("租户不存在");
        }

        if (StringUtils.isEmpty(tenant.getAirportUrl())) {
            log.info("调用机场平台，操作无人机: 机场平台URL为空");
            throw new ServiceException("机场平台URL为空");
        }
        return tenant;
    }


}