package com.tuoheng.admin.service.warningrecord.query;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.tuoheng.admin.entity.domain.Warning;
import com.tuoheng.admin.entity.domain.WarningRecord;
import com.tuoheng.admin.entity.request.warningrecord.QueryWarningRecordListByWarningIdRequest;
import com.tuoheng.admin.enums.MarkEnum;
import com.tuoheng.admin.mapper.WarningMapper;
import com.tuoheng.admin.mapper.WarningRecordMapper;
import com.tuoheng.common.exception.ServiceException;
import com.tuoheng.common.utils.JsonResult;
import com.tuoheng.system.entity.User;
import com.tuoheng.system.utils.ShiroUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 查询预警记录业务层处理
 *
 * @author wanjing
 * @team tuoheng
 * @date 2022-11-22
 */
@Slf4j
@Service
public class QueryWarningRecordListByWarningIdService {

    @Autowired
    private WarningMapper warningMapper;

    @Autowired
    private WarningRecordMapper warningRecordMapper;

    public JsonResult getListByWarningId(QueryWarningRecordListByWarningIdRequest request) {
//        log.info("进入根据预警ID查询预警记录列表业务");

        User user = ShiroUtils.getUserInfo();
        Integer tenantId = user.getTenantId();
        request.setTenantId(tenantId);

        JsonResult result = this.check(tenantId, request);
        if (0 != result.getCode()) {
            log.info("进入根据预警ID查询预警记录列表业务：校验失败：{}", result.getMsg());
            return result;
        }
        List<WarningRecord> warningRecordList = warningRecordMapper.getList(request);
        if (CollectionUtil.isEmpty(warningRecordList)) {
            log.info("预警记录列表数据为空");
        }
        return JsonResult.success(warningRecordList);
    }

    /**
     * 检查参数
     *
     * @param tenantId
     * @param request
     * @return
     */
    private JsonResult check(Integer tenantId, QueryWarningRecordListByWarningIdRequest request) {
        // 判断预警id是否为空
        if (ObjectUtil.isNotNull(request.getWarningId())) {
            throw new ServiceException("预警ID为空");
        }
        Warning warning = warningMapper.selectOne(new LambdaQueryWrapper<Warning>()
                .eq(Warning::getId, request.getWarningId())
                .eq(Warning::getTenantId, tenantId)
                .eq(Warning::getMark, MarkEnum.VALID.getCode()));
        if (ObjectUtil.isNull(warning)) {
            throw new ServiceException("预警信息不存在");
        }
        return JsonResult.success();
    }

}
